@@ -41,9 +41,9 @@ class Factifier(Chain):
     )
 
     def parse(self, results: list[str]):
-        return self._parse(results, prefix="-")
+        return self._parse(results, prefix=r"-+")
 
     def factify(self, doc: Document) -> list[str]:
         chain = LLMChain(llm=self.llm, prompt=self.PROMPT_TEMPLATE)
         results = "-" + self.cached("factify", chain, doc)
-        return self._parse(results.splitlines())
+        return self.parse(results.splitlines())
