@@ -1,7 +1,7 @@
 from pathlib import Path
+from typing import Optional
 
 from summ.classify.classes import Classes
-from summ.embed.embedder import Embedder
 from summ.pipeline import Pipeline
 from summ.query.querier import Querier
 
@@ -10,12 +10,18 @@ class Summ:
     def __init__(self, index: str = "sum-facts"):
         self.index = index
 
-    def populate(self, path: Path, parallel: bool = True):
-        pipe = Pipeline.default(path, self.index)
+    def populate(
+        self,
+        path: Path,
+        parallel: bool = True,
+        pipe: Optional[Pipeline] = None,
+    ):
+        pipe = pipe or Pipeline.default(path, self.index)
         try:
+            print("Creating index, this may take a while...")
             pipe.embedder.create_index()
         except Exception:
-            pass
+            print("Index already exists!")
 
         pipe.run(parallel=parallel)
 
